Skip to main content

Install

Install system av tools

% sudo apt-get install -y ffmpeg sox rtmpdump

or

% brew install ffmpeg sox rtmpdump

Install with pip

% pip3 install yt-helper

Usage

The yt-download script is provided

% venv/bin/yt-download --help
Usage: yt-download [OPTIONS] [ARGS]...

  Wrapper to 'av_from_url'

  - args: urls or filenames containing urls

Options:
  -o, --template TEXT       string representing generated filenames
  -h, --max-height INTEGER  maximum height of video (i.e. 1080, 720, 480,
                            240.. default 720)
  -p, --playlist            Allow downloading entire playlist
  -t, --thumbnail           Download thumbnail image of video
  -d, --description         Download description of video to a file
  -s, --subtitles           Embed subtitles in the downloaded video
  -a, --audio-only          Don't keep the video file if one was downloaded
  -m, --mp3                 Convert downloaded audio to MP3 file
  -v, --verbose             Show extra debugging output
  --help                    Show this message and exit.

Optional Installs

Collections/models (QUERIES, URLS, FILES, COMMENTS)

In order to make use of the QUERIES, URLS, FILES, and COMMENTS collections, you must also install the redis-helper package and have a Redis server running.

If the collections/models are available, some functions will save relevant info to them.

See: https://github.com/kenjyco/redis-helper#intro

If you don’t have docker installed, install Redis and start server

% sudo apt-get install -y redis-server

or

% brew install redis
% brew services start redis

Install with pip

% pip3 install redis-helper

Metadata

Release files for yt-helper 0.2.11

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Built distribution (wheel)

Table of built distributions (wheels) for yt-helper 0.2.11
File Interpreter ABI Platform
yt_helper-0.2.11-py3-none-any.whl Python 3 none any Details

Release files / yt_helper-0.2.11-py3-none-any.whl

Download URL yt_helper-0.2.11-py3-none-any.whl
Size 7.4 kB
Tags Python 3
SHA-256 checksum
How to use checksums
76d5af47879192997cdeced0a09b9cbc77ff0542899f3601e45e0e53f2e754b0
BLAKE2b-256 checksum
How to use checksums
9610f31c8dc147ed11393c430633c5fcba135a0a9a61fb7a2b194f8b60f60b2d
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.1 CPython/3.8.10

Release history Release notifications | RSS feed

This release

0.2.11 This release

1 release file

0.2.10

1 release file

0.2.9

1 release file

0.2.8

1 release file

0.2.7

1 release file

0.2.6

1 release file

0.2.5

1 release file

0.2.4

1 release file

0.2.3

1 release file

0.2.2

1 release file

0.2.1

1 release file

0.2.0

1 release file

0.1.17

1 release file

0.1.16

1 release file

0.1.15

1 release file

0.1.14

1 release file

0.1.13

1 release file

0.1.12

1 release file

0.1.11

1 release file

0.1.10

1 release file

0.1.9

1 release file

0.1.8

1 release file

0.1.7

1 release file

0.1.6

1 release file

0.1.5

1 release file

0.1.4

1 release file

0.1.3

1 release file

0.1.2

1 release file

0.1.1

1 release file

0.1.0

1 release file

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page